# SOIKA
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Documentation Status](https://readthedocs.org/projects/soika/badge/?version=latest)](https://soika.readthedocs.io/ru/latest/?badge=latest)
[![PythonVersion](https://img.shields.io/badge/python-3.11-blue)](https://pypi.org/project/scikit-learn/)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Tests](https://github.com/GeorgeKontsevik/soika/actions/workflows/2dev_ci_on_pr.yaml/badge.svg?branch=dev)](https://github.com/GeorgeKontsevik/soika/actions/workflows/2dev_ci_on_pr.yaml)

[![soika_community_chat](https://img.shields.io/badge/-community-blue?logo=telegram)](https://t.me/soika_community)
[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1wCUJAqlq9GMKw1wpTsWrzYwr10pWDeHv?usp=sharing)

<img align="right" src="docs/logo/logo.png" alt="Your Banner" width="20%">

**SOIKA** - это библиотека, нацеленная на обогащение цифровых моделей городов данными, получаемыми из текстовых данных цифрового следа горожан, 
а также на моделирование вернакулярной оценки качества городской среды.

Основным ее элементом является конструируемый 
пространственно-семантический гиперграф, пополняемый при помощи машинного распознавания городских сущностей и локаций.

SOIKA также предоставляет методы для моделирования
социальных рисков относительно эмоциональной оценки упоминаемых мест.


Данные, полученные после сбора и обработки данных в SLOYK'е, представляют собой пространственно-семантический гиперграф:
<img align="center" src="images/gexample.png" alt="Your Banner" width="100%">



## Лицензия

Проект имеет лицензию [MIT License](./LICENSE).

## Контакты

- [НЦКР](https://actcognitive.org/o-tsentre/kontakty) - Национальный Центр Когнитивных Разработок.
- [ИДУ](https://idu.itmo.ru/en/contacts/contacts.htm) - Институт Дизайна и Урбанистики.
- Если у вас есть вопросы или предложения, вы можете связаться с нами по следующему адресу:
asantonov@itmo.ru (Александр Антонов, Project Lead)
kontsevik@itmo.ru (just in case).

## Цитирование

``` bibtex
@inproceedings{antonov2024transformation,
  title={Transformation of Local Communities from Neighborhoods to Urban Commons in the Production of Social Representations of Space},
  author={Antonov, Aleksandr and Gornova, Galina and Kontsevik, Georgii and Turkov, Leonid and Vorona, Vladimir and Mityagin, Sergey},
  booktitle={International Conference on Computational Science and Its Applications},
  pages={436--447},
  year={2024},
  organization={Springer}
}
```
---
